@@ -23,14 +23,13 @@ sub task {
     return 1;
 }
 
-# TODO this method is EXPERIMENTAL, needs tests and code cleaning.
-sub to_hash {
+sub to_hashref {
     my $self = shift;
 
     return {
-        id     => $self->id,
-        source => $self->source,
-        target => $self->target,
+        id        => $self->id,
+        source_id => $self->source->id,
+        target_id => $self->target->id,
     };
 }
 
@@ -65,5 +64,11 @@ PNI::Edge - is used to connect
 
 If edge is connected, pass data from target to source.
 
+=head2 to_hash
+
+    my $edge_hashref = $edge->to_hashref;
+
+Returns an hash ref representing the edge.
+
 =cut
 
